@@ -16,9 +16,10 @@ from PySide6 import QtCore, QtGui, QtWidgets
 from fastflix.language import t
 from fastflix.models.fastflix_app import FastFlixApp
 from fastflix.models.video import Video
-from fastflix.ff_queue import get_queue, save_queue
+from fastflix.ff_queue import get_queue, save_queue, save_queue_async
 from fastflix.resources import get_icon, get_bool_env
 from fastflix.shared import no_border, open_folder, yes_no_message, message, error_message
+from fastflix.ui_scale import scaler
 from fastflix.widgets.panels.abstract_list import FlixList
 from fastflix.exceptions import FastFlixInternalException
 from fastflix.windows_tools import allow_sleep_mode, prevent_sleep_mode
@@ -95,23 +96,22 @@ class EncodeItem(QtWidgets.QTabWidget):
         del settings
 
         open_button = QtWidgets.QPushButton(
-            QtGui.QIcon(get_icon("play", self.parent.app.fastflix.config.theme)), t("Open Directory")
+            self.parent.app.style().standardIcon(QtWidgets.QStyle.StandardPixmap.SP_DirOpenIcon), t("Open Directory")
         )
-        open_button.setLayoutDirection(QtCore.Qt.RightToLeft)
-        open_button.setIconSize(QtCore.QSize(14, 14))
+        open_button.setIconSize(scaler.scale_size(12, 12))
         open_button.clicked.connect(lambda: open_folder(video.video_settings.output_path.parent))
 
         view_button = QtWidgets.QPushButton(
-            QtGui.QIcon(get_icon("play", self.parent.app.fastflix.config.theme)), t("Watch")
+            self.parent.app.style().standardIcon(QtWidgets.QStyle.StandardPixmap.SP_MediaPlay), t("Watch")
         )
-        view_button.setLayoutDirection(QtCore.Qt.RightToLeft)
-        view_button.setIconSize(QtCore.QSize(14, 14))
+        view_button.setIconSize(scaler.scale_size(12, 12))
         view_button.clicked.connect(
             lambda: QtGui.QDesktopServices.openUrl(QtCore.QUrl.fromLocalFile(str(video.video_settings.output_path)))
         )
 
-        open_button.setStyleSheet(no_border)
-        view_button.setStyleSheet(no_border)
+        button_style = no_border + " QPushButton { padding: 0 4px; }"
+        open_button.setStyleSheet(button_style)
+        view_button.setStyleSheet(button_style)
 
         add_retry = False
         status = t("Ready to encode")
@@ -131,8 +131,10 @@ class EncodeItem(QtWidgets.QTabWidget):
         if not self.video.status.running:
             self.widgets.cancel_button.clicked.connect(lambda: self.parent.remove_item(self.video))
             self.widgets.reload_button.clicked.connect(lambda: self.parent.reload_from_queue(self.video))
-            self.widgets.cancel_button.setFixedWidth(25)
-            self.widgets.reload_button.setFixedWidth(25)
+            self.widgets.cancel_button.setFixedWidth(scaler.scale(20))
+            self.widgets.cancel_button.setIconSize(scaler.scale_size(12, 12))
+            self.widgets.reload_button.setFixedWidth(scaler.scale(20))
+            self.widgets.reload_button.setIconSize(scaler.scale_size(12, 12))
         else:
             self.widgets.cancel_button.hide()
             self.widgets.reload_button.hide()
@@ -154,7 +156,8 @@ class EncodeItem(QtWidgets.QTabWidget):
             grid.addWidget(open_button, 0, 9)
         elif add_retry:
             grid.addWidget(self.widgets.retry_button, 0, 8)
-            self.widgets.retry_button.setFixedWidth(25)
+            self.widgets.retry_button.setFixedWidth(scaler.scale(20))
+            self.widgets.retry_button.setIconSize(scaler.scale_size(12, 12))
             self.widgets.retry_button.clicked.connect(lambda: self.parent.retry_video(self.video))
 
         right_buttons = QtWidgets.QHBoxLayout()
@@ -170,9 +173,13 @@ class EncodeItem(QtWidgets.QTabWidget):
     def init_move_buttons(self):
         layout = QtWidgets.QVBoxLayout()
         layout.setSpacing(0)
-        self.widgets.up_button.setFixedWidth(20)
+        self.widgets.up_button.setFixedWidth(scaler.scale(17))
+        self.widgets.up_button.setFixedHeight(scaler.scale(20))
+        self.widgets.up_button.setIconSize(scaler.scale_size(12, 12))
         self.widgets.up_button.clicked.connect(lambda: self.parent.move_up(self))
-        self.widgets.down_button.setFixedWidth(20)
+        self.widgets.down_button.setFixedWidth(scaler.scale(17))
+        self.widgets.down_button.setFixedHeight(scaler.scale(20))
+        self.widgets.down_button.setIconSize(scaler.scale_size(12, 12))
         self.widgets.down_button.clicked.connect(lambda: self.parent.move_down(self))
         layout.addWidget(self.widgets.up_button)
         layout.addWidget(self.widgets.down_button)
@@ -230,8 +237,10 @@ class EncodingQueue(FlixList):
         self.load_queue_button.setFixedWidth(110)
 
         self.priority_widget = QtWidgets.QComboBox()
-        self.priority_widget.addItems(["Realtime", "High", "Above Normal", "Normal", "Below Normal", "Idle"])
-        self.priority_widget.setCurrentIndex(3)
+        self.priority_widget.addItems(
+            ([] if reusables.win_based else ["Realtime"]) + ["High", "Above Normal", "Normal", "Below Normal", "Idle"]
+        )
+        self.priority_widget.setCurrentText("Normal")
         self.priority_widget.currentIndexChanged.connect(self.set_priority)
 
         self.clear_queue = QtWidgets.QPushButton(
@@ -302,8 +311,6 @@ class EncodingQueue(FlixList):
             self.queue_startup_check()
         except Exception:
             logger.exception("Could not load queue as it is outdated or malformed. Deleting for safety.")
-            # with self.app.fastflix.queue_lock:
-            #     save_queue([], queue_file=self.app.fastflix.queue_path, config=self.app.fastflix.config)
 
     def queue_startup_check(self, queue_file=None):
         new_queue = get_queue(queue_file or self.app.fastflix.queue_path)
@@ -337,7 +344,7 @@ class EncodingQueue(FlixList):
         #         metadata_file.unlink(missing_ok=True)
 
         self.new_source()
-        save_queue(self.app.fastflix.conversion_list, self.app.fastflix.queue_path, self.app.fastflix.config)
+        # No explicit save needed - new_source() triggers reorder() which saves the queue
 
     def manually_save_queue(self):
         filename = QtWidgets.QFileDialog.getSaveFileName(
@@ -393,7 +400,7 @@ class EncodingQueue(FlixList):
         if self.tracks:
             self.tracks[0].widgets.up_button.setDisabled(True)
             self.tracks[-1].widgets.down_button.setDisabled(True)
-        save_queue(self.app.fastflix.conversion_list, self.app.fastflix.queue_path, self.app.fastflix.config)
+        save_queue_async(self.app.fastflix.conversion_list, self.app.fastflix.queue_path, self.app.fastflix.config)
 
     def new_source(self):
         for i in range(len(self.tracks) - 1, -1, -1):
@@ -438,7 +445,7 @@ class EncodingQueue(FlixList):
 
         if not part_of_clear:
             self.new_source()
-        save_queue(self.app.fastflix.conversion_list, self.app.fastflix.queue_path, self.app.fastflix.config)
+            # Queue is saved by new_source() -> reorder() -> save_queue_async()
 
     def reload_from_queue(self, video):
         try:
@@ -549,7 +556,7 @@ class EncodingQueue(FlixList):
 
         self.app.fastflix.conversion_list.append(copy.deepcopy(self.app.fastflix.current_video))
         self.new_source()
-        save_queue(self.app.fastflix.conversion_list, self.app.fastflix.queue_path, self.app.fastflix.config)
+        # No explicit save needed - new_source() triggers reorder() which saves the queue
 
     def run_after_done(self):
         if not self.after_done_action:
